import os

from datetime import datetime as dt

from oscars_mgmnt_clms.file_object import ObjectInfo
from oscars_mgmnt_clms.parser.base import BaseParser
from oscars_mgmnt_clms.parser.filename import parse_fname_date, FilenameParser


class CLMSGlobalParser_GeoTIFF(FilenameParser):
    """Parser used to build GeoJSON metadata from CLMS Global Land products in netCDF format"""

    def __init__(self):
        super().__init__(template="CLMS_GLOBAL.template")

    def convert(self, product_file_info):
        # Initialize values dict
        values = {}

        # example of supported filenames:
        #   c_gls_LSP300-AMPL-S1_202301010000_GLOBE_OLCI_V1.0.1.tiff
        #   c_gls_LSP300-SOSD-S2_202301010000_GLOBE_OLCI_V1.0.1.tiff
        fn = os.path.abspath(product_file_info.get_product_path())

        # filename without extension
        file_name = os.path.basename(fn).rpartition(".")[0]
        file_name_parts = file_name.split("_")

        nominaldatetime = parse_fname_date(file_name_parts[3])
        values["nominaldatetime"] = nominaldatetime.isoformat() + "Z"

        product_type, separator, product_group = file_name_parts[2].partition("-")

    @property
    def filetype(self) -> str:
        return "geotiff"

